@@ -26,7 +26,7 @@ latestOfficial=`${tools_dir}/grib_get -p tablesVersionLatestOfficial $sample2`
 
 latest_codetable_file=$ECCODES_DEFINITION_PATH/grib2/tables/$latestOfficial/4.0.table
 awk '$1 !~ /#/ && $1 < 65000 {print $1}' $latest_codetable_file | while read pdtn; do
-    if [ ! -f "$ECCODES_DEFINITION_PATH/grib2/template.4.$pdtn.def" ]; then
+    if [ ! -f "$ECCODES_DEFINITION_PATH/grib2/templates/template.4.$pdtn.def" ]; then
         echo "GRIB2 template for product definition $pdtn does not exist!"
         exit 1
     fi
@@ -180,6 +180,61 @@ test_PDTN_conversions 57 67
 test_PDTN_conversions 58 68
 test_PDTN_conversions 71 73
 
+# ECC-1779: Deprecated and experimental templates
+# ------------------------------------------------
+grib_check_key_equals $sample2 isTemplateDeprecated,isTemplateExperimental '0 0'
+
+$tools_dir/grib_set -s productDefinitionTemplateNumber=44 $sample2 $temp
+grib_check_key_equals $temp isTemplateDeprecated,isTemplateExperimental '1 0'
+
+$tools_dir/grib_set -s productDefinitionTemplateNumber=10 $sample2 $temp
+grib_check_key_equals $temp isTemplateDeprecated,isTemplateExperimental '0 1'
+
+$tools_dir/grib_set -s gridType=cross_section $sample2 $temp
+grib_check_key_equals $temp isTemplateDeprecated,isTemplateExperimental '0 1'
+$tools_dir/grib_set -s gridType=time_section $sample2 $temp
+grib_check_key_equals $temp isTemplateDeprecated,isTemplateExperimental '0 1'
+
+# Use of eps key (for local section)
+# -----------------------------------
+input=$ECCODES_SAMPLES_PATH/reduced_gg_pl_32_grib2.tmpl
+$tools_dir/grib_set -s stepType=accum,eps=1 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '11'
+
+#17 Ensemble mean
+#18 Ensemble standard deviation
+$tools_dir/grib_set -s type=17,stepType=accum,eps=1 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber,derivedForecast '12 0'
+
+$tools_dir/grib_set -s type=18,stepType=accum,eps=1 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber,derivedForecast '12 4'
+
+# Chemicals
+$tools_dir/grib_set -s paramId=217019,stepType=instant,eps=0 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '40'
+
+$tools_dir/grib_set -s paramId=217019,stepType=instant,eps=1 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '41'
+
+$tools_dir/grib_set -s paramId=217019,stepType=accum,eps=0 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '42'
+
+$tools_dir/grib_set -s paramId=217019,stepType=accum,eps=1 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '43'
+
+# Aerosol 210072
+$tools_dir/grib_set -s paramId=210072,stepType=instant,eps=0 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '48'
+
+$tools_dir/grib_set -s paramId=210072,stepType=instant,eps=1 $input $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '45'
+
+#$tools_dir/grib_set -s paramId=210072,stepType=accum,eps=0 $input $temp
+#grib_check_key_equals $temp productDefinitionTemplateNumber '42'
+
+#$tools_dir/grib_set -s paramId=210072,stepType=accum,eps=1 $input $temp
+#grib_check_key_equals $temp productDefinitionTemplateNumber '43'
+
 
 # Clean up
 rm -f $temp $temp1 $temp2 $tempFilt $tempText
